@@ -64,8 +64,13 @@ class WiseAccount:
     def get_cash_account(self, currency: global_common.Currency) -> CashAccount:
         return typing.cast(CashAccount, list(filter(lambda account: account.currency == currency and isinstance(account, CashAccount), self.account_list))[0])
 
-    def get_reserve_account(self, currency: global_common.Currency, reserve_account_name: str) -> ReserveAccount:
-        return typing.cast(ReserveAccount, list(filter(lambda account: account.currency == currency and isinstance(account, ReserveAccount) and account.name == reserve_account_name,self.account_list))[0])
+    def get_reserve_account(self, currency: global_common.Currency, reserve_account_name: str, create_if_unavailable: bool = False) -> ReserveAccount:
+        reserve_account: ReserveAccount = typing.cast(ReserveAccount, list(filter(lambda account: account.currency == currency and isinstance(account, ReserveAccount) and account.name == reserve_account_name,self.account_list))[0])
+
+        if reserve_account is None:
+            return ReserveAccount.create_reserve_account(self.api_key, reserve_account_name, currency, self.profile_type)
+
+        return reserve_account
 
     def get_exchange_rate(self, from_currency: global_common.Currency, to_currency: global_common.Currency) -> ExchangeRate:
         return ExchangeRate.get(self.api_key, from_currency, to_currency)
